@@ -7,7 +7,7 @@
 #
 # Duplicity is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 3 of the License, or (at your
+# Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.
 #
 # Duplicity is distributed in the hope that it will be useful, but
@@ -22,7 +22,7 @@
 import os
 
 import duplicity.backend
-from duplicity.errors import *
+from duplicity.errors import * #@UnusedWildImport
 
 hsi_command = "hsi"
 class HSIBackend(duplicity.backend.Backend):
@@ -60,8 +60,7 @@ class HSIBackend(duplicity.backend.Backend):
         return filter(lambda x: x, l)
 
     def delete(self, filename_list):
-        assert len(filename_ist) > 0
-        pathlist = map(lambda fn: self.remote_prefix + fn, filename_list)
+        assert len(filename_list) > 0
         for fn in filename_list:
             commandline = '%s "rm %s%s"' % (hsi_command, self.remote_prefix, fn)
             self.run_command(commandline)
