@@ -26,12 +26,17 @@ associates stat information with filenames
 
 """
 
-import stat, os, errno, socket, time, re, gzip
+import stat, errno, socket, time, re, gzip
 
+from duplicity import file_naming
+from duplicity import globals
+from duplicity import gpg
+from duplicity import tarfile
+from duplicity import util
 from duplicity import librsync
-from duplicity import log
+from duplicity import log #@UnusedImport
 from duplicity import dup_time
-from duplicity.lazy import *
+from duplicity.lazy import * #@UnusedWildImport
 
 _copy_blocksize = 64 * 1024
 _tmp_path_counter = 1
@@ -86,10 +91,9 @@ class ROPath:
             raise PathException("Unknown type")
 
         self.mode = stat.S_IMODE(st_mode)
-        # The following can be replaced with major(), minor() macros
-        # in later versions of python (>= 2.3 I think)
         if self.type in ("chr", "blk"):
-            self.devnums = (self.stat.st_rdev >> 8, self.stat.st_rdev & 0xff)
+            self.devnums = (os.major(self.stat.st_rdev),
+                            os.minor(self.stat.st_rdev))
 
     def blank(self):
         """Black out self - set type and stat to None"""
@@ -259,7 +263,7 @@ class ROPath:
                     ti.type = tarfile.BLKTYPE
                 ti.devmajor, ti.devminor = self.devnums
             else:
-                raise PathError("Unrecognized type " + str(self.type))
+                raise PathException("Unrecognized type " + str(self.type))
 
             ti.mode = self.mode
             ti.uid, ti.gid = self.stat.st_uid, self.stat.st_gid
@@ -414,6 +418,7 @@ class ROPath:
             os.mkdir(other.name)
         elif self.issym():
             os.symlink(self.symtext, other.name)
+            os.lchown(other.name, self.stat.st_uid, self.stat.st_gid)
             other.setdata()
             return # no need to copy symlink attributes
         elif self.isfifo():
@@ -431,9 +436,9 @@ class ROPath:
     def copy_attribs(self, other):
         """Only copy attributes from self to other"""
         if isinstance(other, Path):
-            os.chown(other.name, self.stat.st_uid, self.stat.st_gid)
-            os.chmod(other.name, self.mode)
-            os.utime(other.name, (time.time(), self.stat.st_mtime))
+            util.maybe_ignore_errors(lambda: os.chown(other.name, self.stat.st_uid, self.stat.st_gid))
+            util.maybe_ignore_errors(lambda: os.chmod(other.name, self.mode))
+            util.maybe_ignore_errors(lambda: os.utime(other.name, (time.time(), self.stat.st_mtime)))
             other.setdata()
         else:
             # write results to fake stat object
@@ -458,14 +463,27 @@ class Path(ROPath):
     """
     regex_chars_to_quote = re.compile("[\\\\\\\"\\$`]")
 
+    def rename_index(self, index):
+        if not globals.rename or not index:
+            return index # early exit
+        path = os.path.normcase(os.path.join(*index))
+        tail = []
+        while path and path not in globals.rename:
+            path, extra = os.path.split(path)
+            tail.insert(0, extra)
+        if path:
+            return globals.rename[path].split(os.sep) + tail
+        else:
+            return index # no rename found
+
     def __init__(self, base, index = ()):
         """Path initializer"""
         # self.opened should be true if the file has been opened, and
         # self.fileobj can override returned fileobj
         self.opened, self.fileobj = None, None
         self.base = base
-        self.index = index
-        self.name = os.path.join(base, *index)
+        self.index = self.rename_index(index)
+        self.name = os.path.join(base, *self.index)
         self.setdata()
 
     def setdata(self):
@@ -474,7 +492,7 @@ class Path(ROPath):
             self.stat = os.lstat(self.name)
         except OSError, e:
             err_string = errno.errorcode[e[0]]
-            if err_string == "ENOENT" or err_string == "ENOTDIR":
+            if err_string == "ENOENT" or err_string == "ENOTDIR" or err_string == "ELOOP":
                 self.stat, self.type = None, None # file doesn't exist
                 self.mode = None
             else:
@@ -522,10 +540,10 @@ class Path(ROPath):
         self.setdata()
 
     def mkdir(self):
-        """Make a directory at specified path"""
+        """Make directory(s) at specified path"""
         log.Info(_("Making directory %s") % (self.name,))
         try:
-            os.mkdir(self.name)
+            os.makedirs(self.name)
         except OSError:
             if (not globals.force):
                 raise PathException("Error creating directory %s" % (self.name,), 7)
@@ -719,9 +737,9 @@ class DupPath(Path):
             if not gpg_profile:
                 gpg_profile = globals.gpg_profile
             if mode == "rb":
-                return gpg.GPGFile(None, self, gpg_profile)
+                return gpg.GPGFile(False, self, gpg_profile)
             elif mode == "wb":
-                return gpg.GPGFile(1, self, gpg_profile)
+                return gpg.GPGFile(True, self, gpg_profile)
         else:
             return self.open(mode)
 
@@ -736,10 +754,3 @@ class PathDeleter(ITRBranch):
         return not path.isdir()
     def fast_process(self, index, path):
         path.delete()
-
-
-# Wait until end to avoid circular module trouble
-from duplicity import file_naming
-from duplicity import globals
-from duplicity import gpg
-from duplicity import tarfile
